summaryrefslogtreecommitdiff
path: root/frontends/gtk/compat.h
diff options
context:
space:
mode:
Diffstat (limited to 'frontends/gtk/compat.h')
-rw-r--r--frontends/gtk/compat.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/frontends/gtk/compat.h b/frontends/gtk/compat.h
index feb0abe28..8ef2ed505 100644
--- a/frontends/gtk/compat.h
+++ b/frontends/gtk/compat.h
@@ -178,16 +178,16 @@ enum {
/**
* Sets the icon shown in the entry at the specified position from a
* stock image.
*
- * Compatability interface for original deprecated in GTK 3.10
+ * Compatability interface for original introduced in 2.16
*
* \param entry The entry widget to set the icon on.
* \param icon_pos The position of the icon.
* \param stock_id the name of the stock item.
*/
-void nsgtk_entry_set_icon_from_stock(GtkWidget *entry, GtkEntryIconPosition icon_pos, const gchar *stock_id);
+void nsgtk_entry_set_icon_from_icon_name(GtkWidget *entry, GtkEntryIconPosition icon_pos, const gchar *stock_id);
/**
* Creates a GtkImage displaying a stock icon.
@@ -178,16 +178,16 @@ enum {
/**
- * Sets the icon shown in the entry at the specified position from a
- * stock image.
+ * Sets the icon shown in the entry at the specified position from an
+ * icon name.
*